@echo off
cls

rem variables
rem =============================================
rem vesrion of Celestia Origin
set "CO_VERSION=v.9 (30.08.2019)"

rem version of Celestia
set "CEL_VERSION=1.6.1"

rem basic testing path to original Celestia
set "BASEDIR=C:\Program Files\Celestia"

rem path to script
set "SCRIPTDIR=%~dp0"

rem path to installation archives
for %%i in ("%~dp0\..") do set "ARCHPATH=%%~fi"

rem name of core data archive
set "CORENAME=Celestia Origin v.9 - Core (30.08.2019).7z"

rem name of medres data archive
set "MEDRESNAME=Celestia Origin v.9 - Medres textures (30.08.2019).7z"

rem name of hires data archive
set "HIRESNAME=Celestia Origin v.9 - Hires textures (30.08.2019).7z"

rem name of file containing the removing original Celestia's data
set "backup_list=windows_backup_list.txt"
rem =============================================

echo This is Celestia Origin %CO_VERSION% for Celestia %CEL_VERSION% installation script.

rem admin checking
net session >nul 2>&1
if %errorlevel% neq 0 (
	echo Please run this script file as administrator.
	pause
	exit /b 1
)

echo Checking default Celestia's installation folder: %BASEDIR%...
if exist "%BASEDIR%\celestia.cfg" (goto next)
echo    There is no Celestia's installation in the specified folder.
set "BASEDIR=C:\Program Files (x86)\Celestia"
echo Checking default Celestia installation folder: %BASEDIR%...

:pathset
	if exist "%BASEDIR%\celestia.cfg" (goto next)
	echo    There is no Celestia's installation in the specified folder. Please check the path to it.
	choice /c yn /n /m "Try another path? (y/n)"
	call :answer
	set /P "BASEDIR=Please enter the path to Celestia's installation: "
	goto pathset

:answer
	if %errorlevel% == 2 (
		echo The installation aborted.
		pause
		exit
	)
	exit /b
:next
echo    Celestia's installation was found in %BASEDIR%.

choice /c yn /n /m "Do you want to install Celestia Origin's core data? (y/n)"
call :answer

rem searching core installation archive
:core_search
if exist "%ARCHPATH%\%CORENAME%" (goto continue)
echo File %CORENAME% not found.
set /P "ARCHPATH=Please specify the path to it: "
goto core_search

:continue
rem backup making
rem =============================================
rem create backup directory
rem path to backup folder
set "BACKUPDIR=%BASEDIR%\backup"
if exist "%BACKUPDIR%" (
	choice /c yn /n /m "There is the backup folder already. It's necessary to remove it before installation. Continue? (y/n)"
call :answer
rmdir /s /q "%BACKUPDIR%" >nul
)

echo Creating a backup copy...
mkdir "%BACKUPDIR%"
rem backup necessery data
for /f "UseBackQ delims=" %%i in ("%SCRIPTDIR%\lists\%backup_list%") do (
	if exist "%BASEDIR%\%%i" (
		cd /d "%BASEDIR%"
		rem -sdel removes files after including to archive
		"%SCRIPTDIR%\modules\7z.exe" a -tzip -mx=0 "%BACKUPDIR%\backup.zip" "%%i" -sdel >nul
		) else (
		echo    %%i in Celestia's installation doesn't exist, skipping...
		)
 )

echo The backup data was placed to %BACKUPDIR%\backup.zip.
echo The necessary items were removed.

rem extract files
rem core installation
echo.
echo Installing Celestia Origin's core...
set "UPPERDIR=%BASEDIR%\.."
"%SCRIPTDIR%\modules\7z.exe" x -o"%UPPERDIR%" "%ARCHPATH%\%CORENAME%" Celestia
echo.
echo The core installation completed.
echo.

rem medres installation
choice /c yn /n /m "Do you want to install Celestia Origin's medres data? (y/n)"
if %errorlevel% == 2 (
	echo Skipping...
	goto hires
)
rem searching medres installation archive
:medres_search
if exist "%ARCHPATH%\%MEDRESNAME%" (goto continue2)
echo File %MEDRESNAME% not found.
set /P "ARCHPATH=Please specify the path to it: "
goto :medres_search

:continue2
rem installation
echo.
echo Installing Celestia Origin's medres data...
"%SCRIPTDIR%\modules\7z.exe" x -o"%UPPERDIR%" "%ARCHPATH%\%MEDRESNAME%" Celestia
echo.
echo The medres installation completed.
echo.

:hires
rem hires installation
choice /c yn /n /m "Do you want to install Celestia Origin's hires data? (y/n)"
if %errorlevel% == 2 (
	echo Skipping...
	goto final
)
rem searching hires installation archive
:hires_search
if exist "%ARCHPATH%\%HIRESNAME%" (goto continue3)
echo File %HIRESNAME% not found.
set /P "ARCHPATH=Please specify the path to it: "
goto :hires_search

:continue3
rem installation
echo.
echo Installing Celestia Origin's hires data...
"%SCRIPTDIR%\modules\7z.exe" x -o"%UPPERDIR%" "%ARCHPATH%\%HIRESNAME%" Celestia
echo.
echo The hires installation completed.

:final
echo.
echo The installation completed.

pause
exit
