#!/bin/bash

# variables
#=============================================
# vesrion of Celestia Origin
CO_VERSION="v.9 (30.08.2019)"

# version of Celestia
CEL_VERSION="1.6.1"

# basic testing path to original Celestia
BASEDIR="/Applications/Celestia.app/Contents/Resources/CelestiaResources"

# path to script
SCRIPTDIR="$(dirname $0)"

# path to installation archives
ARCHPATH="$SCRIPTDIR/.."

# name of core data archive
CORENAME="Celestia Origin v.9 - Core (30.08.2019).7z"

# name of medres data archive
MEDRESNAME="Celestia Origin v.9 - Medres textures (30.08.2019).7z"

# name of hires data archive
HIRESNAME="Celestia Origin v.9 - Hires textures (30.08.2019).7z"

# name of file containing the removing original Celestia's data
backup_list="mac_backup_list.txt"
#=============================================

echo "This is Celestia Origin $CO_VERSION for Celestia $CEL_VERSION installation script."

pathset(){
	read -p "Please enter the path to Celestia's installation: " BASEDIR
}

echo -e "Checking default Celestia\047s installation folder: $BASEDIR..."
while [ ! -e "$BASEDIR/celestia.cfg" ]; do
	echo -e "   There is no Celestia\047s installation in the specified folder. Please check the path to it."
	read -p 'Try another path? (yes/no) ' ANSWER
	while [[ "$ANSWER" != 'yes' && "$ANSWER" != 'no' ]]; do
		read -p '   Incorrect answer, please type again: ' ANSWER
	done
	if [ "$ANSWER" = 'no' ]; then
		echo "The installation aborted."
		exit
	fi
	pathset
done

echo -e "   Celestia\047s installation was found in $BASEDIR."

read -p "Do you want to install Celestia Origin's core data? (yes/no) " ANSWER
while [[ "$ANSWER" != 'yes' && "$ANSWER" != 'no' ]]; do
	read -p '   Incorrect answer, please type again: ' ANSWER
done
if [ "$ANSWER" = 'no' ]; then
	echo "The installation aborted."
	exit
fi

# searching core installation archive
while [ ! -e "$ARCHPATH/$CORENAME" ]; do
	echo "File \"$CORENAME\" not found."
	read -p "Please specify the path to it: " ARCHPATH
done


# backup making
#=============================================
# create backup directory
BACKUPDIR="$BASEDIR/backup"
if [ ! -e "$BACKUPDIR" ]; then
	mkdir "$BACKUPDIR"
else
	read -p  "There is the backup folder already. It's necessary to remove it before installation. Continue?" ANSWER
	while [[ "$ANSWER" != 'yes' && "$ANSWER" != 'no' ]]; do
		read -p '   Incorrect answer, please type again: ' ANSWER
	done
	if [ "$ANSWER" = 'no' ]; then
		echo "The installation aborted."
		exit
	fi
	rm -Rf "$BACKUPDIR"
fi

echo "Creating a backup copy..."

# backup necessery data
while IFS= read -r line ; do
	if [ -e "$BASEDIR/$line" ]; then
		if [ -f "$BASEDIR/$line" ]; then
			mkdir -p "$(dirname "$BACKUPDIR/$line")" && cp "$BASEDIR/$line" "$BACKUPDIR/$line"
		fi
		if [ -d "$BASEDIR/$line" ]; then
			mkdir -p "$(dirname "$BACKUPDIR/$line")" && cp -r "$BASEDIR/$line" "$BACKUPDIR/$line"
		fi
	else
		echo -e "   /$line in Celestia\047s installation doesn\047t exist, skipping..."
	fi
done < "$SCRIPTDIR/lists/$backup_list"

echo "The backup data was placed to $BACKUPDIR"
#=============================================

# remove original files
#=============================================
# remove original configuration file
rm -f "$BASEDIR/celestia.cfg"

# remove necessery data
while IFS= read -r line ; do
	if [ -e "$BASEDIR/$line" ]; then
		if [ -f "$BASEDIR/$line" ]; then
			rm "$BASEDIR/$line"
		fi
		if [ -d "$BASEDIR/$line" ]; then
			rm -Rf "$BASEDIR/$line"
		fi
	fi
done < "$SCRIPTDIR/lists/$backup_list"

echo "The necessary items were removed."
#=============================================

# extract files
#=============================================
# core installation
echo -e "\nInstalling Celestia Origin\047s core..."
UPPERDIR="$(dirname "$BASEDIR")"
mv "$UPPERDIR/CelestiaResources" "$UPPERDIR/Celestia"
chmod +x "$SCRIPTDIR/modules/7zr_mac"
"$SCRIPTDIR/modules/7zr_mac" x -o"$UPPERDIR" "$ARCHPATH/$CORENAME" Celestia
mv "$UPPERDIR/Celestia" "$UPPERDIR/CelestiaResources"
echo -e "\nThe core installation completed.\n"

# medres installation
read -p "Do you want to install Celestia Origin's medres data? (yes/no) " ANSWER
while [[ "$ANSWER" != 'yes' && "$ANSWER" != 'no' ]]; do
	read -p '   Incorrect answer, please type again: ' ANSWER
done
if [ "$ANSWER" = 'no' ]; then
	echo -e "   Skipping...\n"
else
	# searching medres installation archive
	while [ ! -e "$ARCHPATH/$MEDRESNAME" ];
	do
		echo "File \"$MEDRESNAME\" not found."
		read -p "Please specify the path to it: " ARCHPATH
	done
	# installation
	echo -e "\nInstalling Celestia Origin\047s medres data..."
	mv "$UPPERDIR/CelestiaResources" "$UPPERDIR/Celestia"
	"$SCRIPTDIR/modules/7zr_mac" x -o"$UPPERDIR" "$ARCHPATH/$MEDRESNAME" Celestia
	mv "$UPPERDIR/Celestia" "$UPPERDIR/CelestiaResources"
	echo -e "The medres installation completed.\n"
fi

# hires installation
read -p "Do you want to install Celestia Origin's hires data? (yes/no) " ANSWER
while [[ "$ANSWER" != 'yes' && "$ANSWER" != 'no' ]]; do
	read -p '   Incorrect answer, please type again: ' ANSWER
done
if [ "$ANSWER" = 'no' ]; then
	echo -e "   Skipping...\n"
else
	# searching hires installation archive
	while [ ! -e "$ARCHPATH/$HIRESNAME" ]; do
		echo "File \"$HIRESNAME\" not found."
		read -p "Please specify the path to it: " ARCHPATH
	done
	mv "$UPPERDIR/CelestiaResources" "$UPPERDIR/Celestia"
	"$SCRIPTDIR/modules/7zr_mac" x -o"$UPPERDIR" "$ARCHPATH/$HIRESNAME" Celestia
	mv "$UPPERDIR/Celestia" "$UPPERDIR/CelestiaResources"
	echo -e "The hires installation completed.\n"
fi

#=============================================

echo "The installation completed."
