#!/bin/bash

# variables
#=============================================
# vesrion of Celestia Origin
CO_VERSION="v.9 (30.08.2019)"

# version of Celestia
CEL_VERSION="1.6.1"

# path to original Celestia
BASEDIR="/Applications/Celestia.app/Contents/Resources/CelestiaResources"

# path to backup folder
BACKUPDIR="$BASEDIR/backup"

# path to script
SCRIPTDIR="$(dirname $0)"

# name of file containing the removing original Celestia's data
remove_list="mac_remove_list.txt"
#=============================================

echo "This is Celestia Origin $CO_VERSION for Celestia $CEL_VERSION uninstallation script."

pathset(){
	read -p "Please enter the path to Celestia's installation: " BASEDIR
}

echo -e "Checking default Celestia\047s installation folder: $BASEDIR..."
while [ ! -e "$BASEDIR/celestia.cfg" ]; do
    echo -e "   There is no Celestia\047s installation in the specified folder. Please check the path to it."
    read -p 'Try another path? (yes/no) ' ANSWER
    while [[ "$ANSWER" != 'yes' && "$ANSWER" != 'no' ]]; do
        read -p '   Incorrect answer, please type again: ' ANSWER
    done
    if [ "$ANSWER" = 'no' ]; then
        echo "The installation aborted."
        exit
    fi
    pathset
done

BACKUPDIR="$BASEDIR/backup"
echo -e "   Celestia Origin\047s installation was found in $BASEDIR."
if [ ! -e "$BACKUPDIR" ]; then
	echo -e "But there is no original Celestia\047s backup data. The recovery can't be performed."
	exit
fi
read -p "Do you want to remove Celestia Origin and restore the original Celestia's data from the backup? (yes/no) " ANSWER
while [[ "$ANSWER" != 'yes' && "$ANSWER" != 'no' ]]; do
	read -p '   Incorrect answer, please type again: ' ANSWER
done
if [ "$ANSWER" = 'no' ]; then
	echo "The uninstalling aborted."
	exit
fi

echo "   Uninstalling Celestia Origin..."
while IFS= read -r line ; do
	if [ -e "$BASEDIR/$line" ]; then
		if [ -f "$BASEDIR/$line" ]; then
			rm "$BASEDIR/$line"
		fi
		if [ -d "$BASEDIR/$line" ]; then
			rm -Rf "$BASEDIR/$line"
		fi
	fi
done < "$SCRIPTDIR/lists/$remove_list"

echo -e "Celestia Origin\047s data was removed."

# restore original Celestia's data
cd "$BACKUPDIR"
rsync -a -r ./ ../
echo -e "The original Celestia\047s data was restored from $BACKUPDIR."

# remove the backup folder
rm -Rf "$BACKUPDIR"
echo "The backup copy was removed."

echo "The uninstallation completed."
